EzTg
==========

.. image:: https://img.shields.io/pypi/v/EzTg
   :target: https://pypi.python.org/pypi/EzTg
   :alt: PyPI version info
.. image:: https://img.shields.io/pypi/pyversions/EzTg
   :target: https://pypi.python.org/pypi/EzTg
   :alt: PyPI supported Python versions
.. image:: https://readthedocs.org/projects/eztg/badge/?version=latest
    :target: https://eztg.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Python api wrapper for telegram, easy to clearly choose every parameter for the method you are calling.

Telegram support group: https://t.me/EzTg_Api
Telergam core api: https://core.telegram.org/bots/api